@@ -1448,4 +1448,15 @@ class DerivedDataApi(metaclass=Singleton):
             return _df
         except Exception as e:
             print(f'failed to get data <err_msg> {e} from derived.stock_debt_val_detail')
-            return False
\ No newline at end of file
+            return False
+
+    def get_fund_type_classification(self):
+        with DerivedDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    FundTypeClassification)
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fund_type_classification <err_msg> {e} from {FundTypeClassification.__tablename__}')
+
+
