@@ -786,8 +786,8 @@ class PortfolioDataApi(metaclass=Singleton):
                     fund_ret = round((fund_nav.iloc[-1].values[0] * fund_share - fund_nav.iloc[0].values[0] * fund_share)*100,2)
                     ret_dict[desc_name_dic[fund_id]] = fund_ret
                 all_ret_dict.append(ret_dict)
-                dic = ((pd.DataFrame(all_ret_dict).T.fillna(0)+1).prod(axis=1)-1).to_dict()
-                dic = {k:round(v,2) for k,v in dic.items()}
+            dic = ((((pd.DataFrame(all_ret_dict)/100).T.fillna(0)+1).prod(axis=1) - 1) * 100).to_dict()
+            dic = {k:round(v,2) for k,v in dic.items()}
 
             _df = pd.DataFrame([dic]).T.sort_values(by=0)
             if _df.shape[0] > 30:
