@@ -597,22 +597,26 @@ class ResearchApi(metaclass=Singleton):
         except Exception as e:
             print(f'Failed to get data <err_msg> {e} from ResearchApi.get_industry_info')
             
-    def get_stock_info_concept(self, stock_id_list):
+    def get_stock_info_concept(self, stock_id_list=None):
         '''股票申万\中信行业分类查询接口'''
         with RawDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                     EmStockConceptInfo
-                ).filter(
-                    EmStockConceptInfo.codes.in_(stock_id_list),
                 )
+                if stock_id_list:
+                    query = query.filter(
+                        EmStockConceptInfo.codes.in_(stock_id_list),
+                    )
                 df = pd.read_sql(query.statement, query.session.bind).drop(columns = "_update_time").set_index("codes")
                 
                 query = db_session.query(
                     EmStockInfo
-                ).filter(
-                    EmStockInfo.CODES.in_(stock_id_list),
                 )
+                if stock_id_list:
+                    query = query.filter(
+                        EmStockInfo.CODES.in_(stock_id_list),
+                    )
                 df = df.join(pd.read_sql(query.statement, query.session.bind).drop(columns = "_update_time").set_index("stock_id")[["bl_sws_ind_code"]])
                 df['bl_sws_ind_code'] = df['bl_sws_ind_code'].map(lambda x: x.split('-') if isinstance(x, str) else None)
                 df = df.explode('bl_sws_ind_code')
@@ -623,7 +627,7 @@ class ResearchApi(metaclass=Singleton):
                     EmIndustryInfo.em_id.in_(df.bl_sws_ind_code.unique().tolist())
                 )
                 _df = pd.read_sql(query.statement, query.session.bind).rename(columns={'em_id':'bl_sws_ind_code'})
-                df = pd.merge(df,_df,on='bl_sws_ind_code')
+                df = pd.merge(df.reset_index(),_df,on='bl_sws_ind_code')
                 return df
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from ResearchApi.get_stock_info_concept')
