@@ -43,7 +43,7 @@ class IndexValProcessLongTerm:
         em_id_to_index_id = self.index_info[['index_id', 'em_id']].set_index('em_id').to_dict()['index_id']
         self.index_val = self.raw_api.get_em_index_val(self.start_time, self.end_time, self.index_info.em_id.to_list())
         self.index_val['index_id'] = self.index_val['em_id'].map(lambda x: em_id_to_index_id[x])
-        self.index_val = self.index_val.drop(columns=['em_id', 'pe_ttm_nn', '_update_time']).set_index(['index_id', 'datetime'])
+        self.index_val = self.index_val.drop(columns=['em_id', '_update_time']).set_index(['index_id', 'datetime'])
         self.index_id_score_method_dict = self.index_info[self.index_info['tag_method'] != 'none'][['index_id', 'tag_method']].set_index('index_id').to_dict()['tag_method']
 
     def calculate(self):
