@@ -65,7 +65,7 @@ class FundIndicatorProcessorGroup:
         self._fund_list = self.fund_info[(self.fund_info.end_date > self.end_date) 
                                        & (self.fund_info.structure_type <= 1)
                                        & (~self.fund_info.wind_class_2.isnull())]
-        fund_nav: pd.DataFrame = self._basic_api.get_fund_nav_with_date(start_date, self.end_date, self._fund_list.fund_id.tolist())
+        fund_nav: pd.DataFrame = self._basic_api.get_fund_nav_with_date(start_date=start_date, end_date=self.end_date, fund_list=self._fund_list.fund_id.tolist())
         self._fund_nav_origin: pd.DataFrame = fund_nav.pivot_table(index='datetime', columns='fund_id', values='adjusted_net_value').reindex(self._trading_days.index).fillna(method='ffill')
         _tm_loads_nav_1 = time.time()
         # 选取成立满半年的 而且近半年波动率不为0，并排除掉异常净值基金
@@ -779,7 +779,7 @@ class FundIndicatorProcessorGroup:
 
 
 if __name__ == '__main__':
-    date = '20210129'
+    date = '20210618'
     fipg = FundIndicatorProcessorGroup(DerivedDataHelper(), 5)
     fipg.process(date, date, pd.to_datetime(date).date())
     # FundIndicatorProcessorGroup.update_history('20201009', 5)
