@@ -1,3 +1,4 @@
+from numpy.lib.function_base import append
 import pandas as pd
 import numpy as np
 import os
@@ -9,7 +10,7 @@ from requests import Session
 from requests.adapters import HTTPAdapter
 from requests.packages.urllib3.util import Retry
 from ...api.raw import RawDataApi
-from ...view.raw_models import YahooIndexPrice, EmBTCFromWeb
+from ...view.raw_models import YahooIndexPrice, EmBTCFromWeb, EmFuturePriceDetail
 from .raw_data_helper import RawDataHelper
 
 
@@ -241,6 +242,121 @@ class WebRawDataDownloader(object):
             traceback.print_exc()
             return False
 
+    def cfe_future_data_download(self, start_date):
+        try:
+            month_part = start_date[:6]
+            date_part = start_date[6:]
+            url = f'http://www.cffex.com.cn/sj/hqsj/rtj/{month_part}/{date_part}/index.xml?id=15'
+            response = requests.get(url)
+
+            tag = response._content.decode('utf8').replace('<?xml version="1.0" encoding="UTF-8"?>\n\n<dailydatas>','')
+            data = tag.splitlines()
+            instrumentid = []
+            tradingday = []
+            openprice = []
+            highestprice = []
+            lowestprice = []
+            closeprice = []
+            preopeninterest = []
+            openinterest = []
+            presettlementprice = []
+            settlementprice = []
+            volume = []
+            turnover = []
+            expiredate = []
+            # 股指期货数据
+            for line in data:
+                if 'IO' in line:
+                    break
+                else:
+                    if 'instrumentid' in line:
+                        instrumentid.append(line.split(' ')[-1].partition("instrumentid>")[-1].partition("</instrumentid")[0])
+                    elif 'tradingday' in line:
+                        tradingday.append(line.split(' ')[-1].partition("tradingday>")[-1].partition("</tradingday")[0])
+                    elif 'openprice' in line:
+                        openprice.append(line.split(' ')[-1].partition("openprice>")[-1].partition("</openprice")[0])
+                    elif 'highestprice' in line:
+                        highestprice.append(line.split(' ')[-1].partition("highestprice>")[-1].partition("</highestprice")[0])
+                    elif 'lowestprice' in line:
+                        lowestprice.append(line.split(' ')[-1].partition("lowestprice>")[-1].partition("</lowestprice")[0])
+                    elif 'closeprice' in line:
+                        closeprice.append(line.split(' ')[-1].partition("closeprice>")[-1].partition("</closeprice")[0])
+                    elif 'preopeninterest' in line:
+                        preopeninterest.append(line.split(' ')[-1].partition("preopeninterest>")[-1].partition("</preopeninterest")[0])
+                    elif 'openinterest' in line:
+                        openinterest.append(line.split(' ')[-1].partition("openinterest>")[-1].partition("</openinterest")[0])
+                    elif 'presettlementprice' in line:
+                        presettlementprice.append(line.split(' ')[-1].partition("presettlementprice>")[-1].partition("</presettlementprice")[0])
+                    elif 'settlementprice' in line:
+                        settlementprice.append(line.split(' ')[-1].partition("settlementprice>")[-1].partition("</settlementprice")[0])
+                    elif 'volume' in line:
+                        volume.append(line.split(' ')[-1].partition("volume>")[-1].partition("</volume")[0])
+                    elif 'turnover' in line:
+                        turnover.append(line.split(' ')[-1].partition("turnover>")[-1].partition("</turnover")[0])
+                    elif 'expiredate' in line:
+                        expiredate.append(line.split(' ')[-1].partition("expiredate>")[-1].partition("</expiredate")[0])
+
+                    else:
+                        pass
+            # 国债期货数据
+            acount = 0
+            for line in data:
+                if 'T' in line:
+                    acount = 1
+                else:
+                    pass
+                if acount == 1:
+                    if 'instrumentid' in line:
+                        instrumentid.append(line.split(' ')[-1].partition("instrumentid>")[-1].partition("</instrumentid")[0])
+                    elif 'tradingday' in line:
+                        tradingday.append(line.split(' ')[-1].partition("tradingday>")[-1].partition("</tradingday")[0])
+                    elif 'openprice' in line:
+                        openprice.append(line.split(' ')[-1].partition("openprice>")[-1].partition("</openprice")[0])
+                    elif 'highestprice' in line:
+                        highestprice.append(line.split(' ')[-1].partition("highestprice>")[-1].partition("</highestprice")[0])
+                    elif 'lowestprice' in line:
+                        lowestprice.append(line.split(' ')[-1].partition("lowestprice>")[-1].partition("</lowestprice")[0])
+                    elif 'closeprice' in line:
+                        closeprice.append(line.split(' ')[-1].partition("closeprice>")[-1].partition("</closeprice")[0])
+                    elif 'preopeninterest' in line:
+                        preopeninterest.append(line.split(' ')[-1].partition("preopeninterest>")[-1].partition("</preopeninterest")[0])
+                    elif 'openinterest' in line:
+                        openinterest.append(line.split(' ')[-1].partition("openinterest>")[-1].partition("</openinterest")[0])
+                    elif 'presettlementprice' in line:
+                        presettlementprice.append(line.split(' ')[-1].partition("presettlementprice>")[-1].partition("</presettlementprice")[0])
+                    elif 'settlementprice' in line:
+                        settlementprice.append(line.split(' ')[-1].partition("settlementprice>")[-1].partition("</settlementprice")[0])
+                    elif 'volume' in line:
+                        volume.append(line.split(' ')[-1].partition("volume>")[-1].partition("</volume")[0])
+                    elif 'turnover' in line:
+                        turnover.append(line.split(' ')[-1].partition("turnover>")[-1].partition("</turnover")[0])
+                    elif 'expiredate' in line:
+                        expiredate.append(line.split(' ')[-1].partition("expiredate>")[-1].partition("</expiredate")[0])
+
+                    else:
+                        pass
+                else:
+                    pass
+
+            # 结算价去空格（是个坑）
+            clear = []
+            for i in range(1,len(settlementprice),2):
+                clear.append(settlementprice[i])
+            dic = {'em_id':instrumentid ,'datetime':tradingday ,'open':openprice,'high':highestprice ,'low':lowestprice,
+                'close':closeprice, 'uni_oi':openinterest,'pre_clear':presettlementprice ,
+                'clear':clear,'uni_volume':volume,'uni_amount':turnover}
+
+            tag = pd.DataFrame(dic)
+            tag.datetime = pd.to_datetime(tag.datetime)
+            tag.em_id = tag.em_id + '.CFE'
+            self._data_helper._upload_raw(tag, EmFuturePriceDetail.__table__.name)
+            return True
+
+        except Exception as e:
+            print(e)
+            traceback.print_exc()
+            return False
+
     def download_all(self, start_date, end_date):
         failed_tasks = []
         if not self.cm_index_price(start_date, end_date):
@@ -255,6 +371,9 @@ class WebRawDataDownloader(object):
         if not self.sina_btc_download():
             failed_tasks.append('sina_btc_close')
 
+        if not self.cfe_future_data_download(start_date):
+            failed_tasks.append('cfe_future_data')
+
         return failed_tasks
 
 
