@@ -12,6 +12,9 @@ from ...view.basic_models import FundNav, FundInfo, FundRate, FundSize, FundRet,
     FundStatusLatest
 from ...view.derived_models import FundAlpha, FundIndicator, FundScoreNew, FundManagerInfo, StyleBox
 from ....constant import ExchangeStatus
+from ....util.calculator import *
+from ...api.derived import DerivedDataApi
+from ...api.research_api import ResearchApi
 from .__init__ import fund_s3_uri
 
 class FundDailyCollectionProcessor(object):
@@ -651,7 +654,70 @@ class FundDailyCollectionProcessor(object):
                     df.loc[fund_id,'top_mng_name'] = _mng_df.loc[fund_id,'fund_manager']
             df = df.reset_index()
             df.total_score = df.total_score.replace(0, None)
-            self.append_data(FundDailyCollection.__tablename__, df)
+            
+            # 新添加的公募数据
+            fund_type_df = DerivedDataApi().get_fund_type_classification()
+            fund_type_df = fund_type_df[fund_type_df['fund_type'] == '公募']
+            fund_type_dic_1 = fund_type_df[['fund_class_1_ori','fund_class_1']].drop_duplicates().set_index('fund_class_1_ori')['fund_class_1'].to_dict()
+            fund_type_dic_2 = fund_type_df[['fund_class_2_ori','fund_class_2']].drop_duplicates().set_index('fund_class_2_ori')['fund_class_2'].to_dict()
+            research_api = ResearchApi()
+            fund_info = research_api.get_fund_info()
+            record_cds = fund_info.fund_id.dropna().tolist()
+
+            col_dic = {
+                'fund_id': 'fund_id',
+                'start_date':'nav_start_date',
+                'end_date':'nav_end_date',
+                'trade_month':'nav_date',
+                'nav_type':'nav_frequency',
+                'fund_nav_completion':'fund_nav_completion',
+                'recent_3m_annual_ret':'recent_3m_ret_annual',
+                'recent_6m_annual_ret':'recent_6m_ret_annual',
+                'y_last_ret_annual':'this_y_ret_annual',
+                'recent_2y_annual_ret':'recent_2y_ret_annual',
+                'recent_2y_ret':'recent_2y_ret',
+                'y_last_mdd':'this_y_mdd',
+                'recent_3m_mdd':'recent_3m_mdd',
+                'recent_6m_mdd':'recent_6m_mdd',
+                'recent_1y_mdd':'recent_1y_mdd',
+                'recent_2y_mdd':'recent_2y_mdd',
+                'calmar':'calmar',
+                'sortino':'sortino',
+            }
+            info_dic = {
+                'fund_id':'fund_id',
+                'wind_class_1':'fund_type_1',
+                'wind_class_2':'fund_type_2',
+            }
+
+            fund_info_part = fund_info[['fund_id','wind_class_1','wind_class_2']]
+            fund_info_part = fund_info_part.rename(columns={'fund_id':'fund_id'})
+            fund_info_part['fund_type_1'] = fund_info_part['wind_class_1'].map(fund_type_dic_1)
+            fund_info_part['fund_type_2'] = fund_info_part['wind_class_2'].map(fund_type_dic_2)
+            fund_info_part = fund_info_part[info_dic.keys()].rename(columns=info_dic)
+            record_cds = fund_info_part.fund_id.dropna().tolist()
+
+            fund_nav = pd.DataFrame()
+            ints = 1000
+            res = []
+            for _i in range(0,len(record_cds),ints):
+                df = research_api.get_fund_nav(fund_id_list = record_cds[_i:_i+ints] ,
+                                                start_date = datetime.date(2000,1,1) ,
+                                                end_date = datetime.datetime.now().date() )
+
+                df = df.pivot_table(columns = "fund_id"  , values = "adjnav" , index = "datetime")
+                for fund_id in df:
+                    df = fund_nav[[fund_id]].dropna()
+                    dic = CalculatorBase.get_stat_result(dates=df.index,values=df[fund_id].values)
+                    dic['fund_id'] = fund_id
+                    res.append(dic)
+            result_df = pd.DataFrame(res)
+            result_df = result_df[col_dic.keys()].rename(columns=col_dic)
+            result = pd.merge(result_df,fund_info_part,on='fund_id')
+            result = result.replace([np.inf, -np.inf], np.nan)
+            data = df.set_index('fund_id').join(result.set_index('fund_id'))
+            data = data.reset_index()
+            self.append_data(FundDailyCollection.__tablename__, data)
 
             print(df)
             return True
