@@ -15,7 +15,7 @@ from ...util.wechat_bot import WechatBot
 from ...util.calculator import Calculator
 from ...constant import EMailParserType
 from ..wrapper.mysql import BasicDatabaseConnector, DerivedDatabaseConnector
-from ..view.basic_models import FOFInfo
+from ..view.basic_models import FOFInfo, HedgeFundEmailRaw
 from ..view.derived_models import FOFUnconfirmedNav, FOFNav
 from ..api.basic import BasicDataApi
 from ..api.derived import DerivedDataApi
@@ -99,6 +99,12 @@ class FOFNAVReader:
                         return x
                 df['fof_id'] = df.fof_id.map(_transform_fof_id)
 
+                if self._manager_id == 'py1':
+                    # 暂时先只存 py1 产品的底层资产的净值数据
+                    self._dump_proprietary_to_db(df)
+
+                # 这里需要 drop 掉虚拟净值
+                df = df.drop(columns='v_nav', errors='ignore')
                 r1 = self._dump_hedge_to_db(df[df.fof_id.isin(self._hedge_list)])
                 if r1 is not None:
                     df_list.append(r1)
@@ -173,6 +179,52 @@ class FOFNAVReader:
                     db_session.close()
         return whole_df
 
+    def _dump_proprietary_to_db(self, df: pd.DataFrame):
+        def _check_after_merged(x: pd.Series, now_df: pd.DataFrame):
+            try:
+                now_data = now_df[(now_df.fund_id == x.fund_id) & (now_df.datetime == x.datetime)]
+                if now_data[['nav', 'acc_net_value', 'v_nav']].iloc[0].astype('float64').equals(x[['nav', 'acc_net_value', 'v_nav']].astype('float64')):
+                    return pd.Series(dtype='object')
+                else:
+                    return x
+            except (KeyError, IndexError):
+                return x
+
+        if 'v_nav' not in set(df.columns.array):
+            return
+        df = df[df.v_nav.notnull()]
+        if df.empty:
+            return
+        df = df.rename(columns={'fof_id': 'fund_id'})
+        df['fof_id'] = self._fof_id
+        assert df.datetime.nunique() == 1, 'should have single datetime'
+        now_df = BasicDataApi().get_hedge_fund_email_raw(self._manager_id, list(df.fund_id.unique()))
+        if now_df is not None and not now_df.empty:
+            # 同产品同日期的净值如果已经存在了且没有变化，就不写DB了
+            now_df = now_df.drop(columns=['update_time', 'create_time', 'is_deleted']).sort_values(by=['manager_id', 'fof_id', 'fund_id', 'datetime']).drop_duplicates(subset=['manager_id', 'fof_id', 'fund_id', 'datetime'], keep='last')
+            now_df = now_df.astype({'nav': 'float64', 'acc_net_value': 'float64', 'v_nav': 'float64'})
+            df = df.reindex(columns=now_df.columns).astype(now_df.dtypes.to_dict())
+            df = df.round(6).merge(now_df.round(6), how='left', on=['manager_id', 'fof_id', 'fund_id', 'datetime', 'nav', 'acc_net_value', 'v_nav'], indicator=True, validate='one_to_one')
+            df = df[df._merge == 'left_only'].drop(columns=['_merge'])
+            if df.empty:
+                return
+            # FIXME 没想到特别好的方法 遍历每一行再check一下
+            df['datetime'] = pd.to_datetime(df.datetime, infer_datetime_format=True).dt.date
+            df = df.apply(_check_after_merged, axis=1, now_df=now_df)
+            if df.empty:
+                return
+            df = df.set_index(['manager_id', 'fof_id', 'fund_id', 'datetime'])
+            print(f'proprietary before update: {df}')
+            df.update(now_df.set_index(['manager_id', 'fof_id', 'fund_id', 'datetime']), overwrite=False)
+            df = df.reset_index()
+            df['datetime'] = df.datetime.map(lambda x: x.date())
+            print(f'proprietary after update: {df}')
+            # 先删后添
+            for fund_id in df.fund_id.unique():
+                BasicDataApi().delete_hedge_fund_email_raw(manager_id=self._manager_id, fof_id=self._fof_id, fund_id=fund_id, date_list=df[df.fund_id == fund_id].datetime.to_list())
+        df.to_sql(HedgeFundEmailRaw.__table__.name, BasicDatabaseConnector().get_engine(), index=False, if_exists='append')
+        return df
+
     def _dump_hedge_to_db(self, df: pd.DataFrame):
         def _check_after_merged(x: pd.Series, now_df: pd.DataFrame):
             try:
