@@ -183,6 +183,7 @@ class FundDailyCollection(Base):
     nav_start_date = Column(DATE) # 开始时间
     nav_end_date = Column(DATE) # 截止时间
     nav_date = Column(CHAR(40)) # 净值日期
+    nav_frequency = Column(CHAR(32)) # 净值周期
     fund_nav_completion = Column(DOUBLE(asdecimal=False))  # 净值完整度
     recent_3m_ret_annual = Column(DOUBLE(asdecimal=False))  # 近3月年化
     recent_6m_ret_annual = Column(DOUBLE(asdecimal=False))  # 近6月年年化
@@ -199,6 +200,7 @@ class FundDailyCollection(Base):
 
     @staticmethod
     def mul_fund_view_to_private_fund_view():
+        # 公募对私募
         return {'fund_id': 'fund_id',
                 'full_name': 'desc_name',
                 'nav_start_date':'start_date',
@@ -209,6 +211,7 @@ class FundDailyCollection(Base):
                 'fund_type_2':'fund_type_2',
                 'company_name':'company',
                 'fund_manager':'manager',
+                'nav_frequency':'nav_frequency',
                 'fund_nav_completion':'fund_nav_completion',
                 'unit_net_value':'unit_net_value',
 
@@ -384,12 +387,13 @@ class FundDailyCollection(Base):
             'purchase_fee_detail':'申购费率详情',
             'redeem_fee_detail':'赎回费率详情',
             'service_fee':'销售服务费率',
-            
+
             'fund_type_1':'一级策略',
             'fund_type_2':'二级策略',
             'nav_start_date':'开始时间',
             'nav_end_date':'截止时间',
             'nav_date':'净值日期',
+            'nav_frequency':'净值周期',
             'fund_nav_completion':'净值完整度',
             'recent_3m_ret_annual':'近3月年化',
             'recent_6m_ret_annual':'近6月年年化',
@@ -873,6 +877,7 @@ class PFFundDailyCollection(Base):
     fund_type_2 = Column(CHAR(40)) # 二级策略
     company = Column(CHAR(80)) # 投资顾问
     manager = Column(CHAR(80)) # 基金经理
+    nav_frequency = Column(CHAR(32)) # 净值周期
     fund_nav_completion = Column(DOUBLE(asdecimal=False))  # 净值完整度
     unit_net_value = Column(DOUBLE(asdecimal=False))  # 单位净值
 
@@ -918,6 +923,7 @@ class PFFundDailyCollection(Base):
             'fund_type_2':'二级策略',
             'company':'投资顾问',
             'manager':'基金经理',
+            'nav_frequency':'净值周期',
             'fund_nav_completion':'净值完整度',
             'unit_net_value':'单位净值',
 
