@@ -19,10 +19,12 @@ class SeriesStatUnit:
     start_date: datetime.date           # 序列的开始时间
     end_date: datetime.date             # 序列的结束时间
     trade_year: float                   # 交易年限
+    trade_month:float                   # 交易月度
     last_unit_nav: float                # 末期单位净值
     annualized_ret: float               # 年化收益
     cumu_ret: float                     # 累计收益
     annualized_vol: float               # 年化波动率
+    fund_nav_completion:float           # 净值完整度
     sharpe: float                       # 夏普率
     recent_year_ret: float              # 最近自然年收益
     recent_1w_ret: float                # 最近1周收益
@@ -180,6 +182,8 @@ class Calculator:
             start_date=res['start_date'],
             end_date=res['end_date'],
             trade_year=res['trade_year'],
+            trade_month=res['trade_month'],
+            fund_nav_completion=res['fund_nav_completion'],
             last_unit_nav=res['last_unit_nav'],
             annualized_ret=res['annual_ret'],
             annualized_vol=res['annual_vol'],
@@ -276,6 +280,8 @@ class Calculator:
             start_date=res['start_date'],
             end_date=res['end_date'],
             trade_year=res['trade_year'],
+            trade_month=res['trade_month'],
+            fund_nav_completion=res['fund_nav_completion'],
             last_unit_nav=res['last_unit_nav'],
             annualized_ret=res['annual_ret'],
             annualized_vol=res['annual_vol'],
