@@ -113,10 +113,15 @@ class CalculatorBase:
         return continue_regress_v
 
     @staticmethod
-    def calc_modify_annual_vol(sr: pd.core.series.Series):
-        # 每个ret(i)除以产生它的时长平方根sqrt(T(i))后，服从独立同分布，可以用来估计日波动率，最后再乘以sqrt(242)年化
-        from ..data.api.basic import BasicDataApi
-        dts = BasicDataApi().get_trading_day_list(start_date=sr.index[0], end_date=sr.index[-1]).set_index('datetime')
+    def calc_modify_annual_vol(sr: pd.core.series.Series):        
+        import json
+        import requests
+        url = 'http://69.231.155.101:8006/api/v1/basic/trade_dates'
+        response = requests.get(url)    
+        dts = json.loads(response._content)['data']['datetime']
+        dts = pd.to_datetime(dts)
+        dts = np.array([i.date() for i in dts])
+        dts = pd.Series(data=1,index=dts)
         sr_ret = sr.pct_change(1)
         sr_ret.name = 'ret'
         sr_ret.index.name = 'this_day'
@@ -510,13 +515,16 @@ class CalculatorBase:
         assert len(dates) == len(values), 'date and port_values has different numbers'
         if len(dates) >= 2:
             sr = pd.Series(values, index=dates).sort_index()
-            sr = sr.set_axis(pd.to_datetime(sr.index), inplace=False).resample(frequency).last().dropna()
+            sr = sr.set_axis(pd.to_datetime(sr.index), inplace=False).resample(frequency).last()
+            b_d = sr.dropna().index[0]
+            e_d = sr.dropna().index[-1]
+            fund_nav_completion = sr.dropna().shape[0] / sr.loc[b_d:e_d].shape[0]
+            sr = sr.dropna()
             sr.index = [i.date() for i in sr.index]
             natural_day_lenth = (sr.index[-1] - sr.index[0]).days
             price_num = sr.dropna().shape[0]
-            nav_density = price_num / natural_day_lenth
+            nav_density = price_num / natural_day_lenth if natural_day_lenth !=0 else 0
             nav_type = CalculatorBase.get_nav_type(values=values, dates=dates)
-            sr = sr.dropna()
             if frequency == '1D':            
                 period_1m = 20
                 period_3m = period_1m * 3
@@ -547,11 +555,12 @@ class CalculatorBase:
                 sr_ret = sr.pct_change(1).iloc[1:]
             start_date = sr.index[0] 
             end_date = sr.index[-1]
-            days = (dates[-1] - dates[0]).days
+            days = (end_date - start_date).days
             last_unit_nav = sr[-1] / sr[0]
             cumu_ret = last_unit_nav - 1
+            trade_month = days / 30
             trade_year = days / CalculatorBase.TOTAL_DAYS_PER_YEAR
-            annual_ret = math.pow(last_unit_nav, CalculatorBase.TOTAL_DAYS_PER_YEAR/days) - 1
+            annual_ret = math.pow(last_unit_nav, CalculatorBase.TOTAL_DAYS_PER_YEAR/days) - 1 if days != 0 else 0
             annual_vol = CalculatorBase.calc_modify_annual_vol(sr)
             _begin_date = sr.index[0]
             recent_ret_res = CalculatorBase.calc_recent_ret(dates=dates,values=values,frequency='1D')
@@ -729,12 +738,14 @@ class CalculatorBase:
                 return {
                     'start_date':start_date,
                     'end_date':end_date,
+                    'trade_month':trade_month,
                     'trade_year':trade_year,
                     'last_unit_nav':last_unit_nav,
                     'cumu_ret':cumu_ret,
                     'annual_ret':annual_ret,
                     'annual_vol':annual_vol,
                     'sharpe':sharpe,
+                    'fund_nav_completion':fund_nav_completion,
                     'recent_year_ret':recent_year_ret,
                     'recent_1w_ret':recent_1w_ret,
                     'recent_1m_ret':recent_1m_ret,
@@ -832,12 +843,14 @@ class CalculatorBase:
                 return {
                     'start_date':start_date,
                     'end_date':end_date,
+                    'trade_month':trade_month,
                     'trade_year':trade_year,
                     'last_unit_nav':last_unit_nav,
                     'cumu_ret':cumu_ret,
                     'annual_ret':annual_ret,
                     'annual_vol':annual_vol,
                     'sharpe':sharpe,
+                    'fund_nav_completion':fund_nav_completion,
                     'recent_year_ret':recent_year_ret,
                     'recent_1w_ret':recent_1w_ret,
                     'recent_1m_ret':recent_1m_ret,
@@ -905,11 +918,13 @@ class CalculatorBase:
             return {
                     'start_date':dates[0] if len(dates) > 0 else None,
                     'end_date':dates[-1] if len(dates) > 0 else None,
+                    'trade_month':0,
                     'trade_year':0,
                     'last_unit_nav':None,
                     'cumu_ret':0,
                     'annual_ret':0,
                     'annual_vol':0,
+                    'fund_nav_completion':0,
                     'sharpe':0,
                     'recent_year_ret':0,
                     'recent_1w_ret':0,
@@ -1222,7 +1237,7 @@ class CalculatorBase:
         return df
 
     @staticmethod
-    def data_resample_weekly_nav(df, rule='1W'):
+    def data_resample_weekly_nav(df, rule='W-FRI'):
         df = df.set_axis(pd.to_datetime(df.index), inplace=False).resample(rule).last()
         df.index = [i.date() for i in df.index]
         df.index.name = 'datetime'
@@ -1236,8 +1251,8 @@ class CalculatorBase:
         tds = pd.to_datetime(sr.index)
         tds = [_.date() for _ in tds]
         sr.index = tds
-        b_d = sr.index[0]
-        e_d = sr.index[-1]
+        b_d = sr.dropna().index[0]
+        e_d = sr.dropna().index[-1]
         url = 'http://69.231.155.101:8006/api/v1/basic/trade_dates'
         response = requests.get(url)    
         dts = json.loads(response._content)['data']['datetime']
